//[mahjong-utils](../../../../index.md)/[mahjongutils.hanhu](../../index.md)/[ParentPoint](../index.md)/[Companion](index.md)/[Sanbaiman](-sanbaiman.md)

# Sanbaiman

[common]\
val [Sanbaiman](-sanbaiman.md): [ParentPoint](../index.md)
